aboutsummaryrefslogtreecommitdiff
path: root/gcc/config/m68k/m68k.h
diff options
context:
space:
mode:
authorrms <rms@138bc75d-0d04-0410-961f-82ee72b054a4>1992-08-12 07:28:03 +0000
committerrms <rms@138bc75d-0d04-0410-961f-82ee72b054a4>1992-08-12 07:28:03 +0000
commit5f85607d2bc26fe5fd3353bbf812993b24d7b5f9 (patch)
tree32b25a58d40b9a38ac34f91138a70587b5a38778 /gcc/config/m68k/m68k.h
parent81673b75dc3ca551f4a569e01fb9029db82659d7 (diff)
(TARGET_68040): Test for 01000 or 0400.
(TARGET_SWITCHES): Rename -m68040 to -m68020-40. Rename -m68040-only to -m68040. git-svn-id: svn+ssh://gcc.gnu.org/svn/gcc/trunk@1805 138bc75d-0d04-0410-961f-82ee72b054a4
Diffstat (limited to 'gcc/config/m68k/m68k.h')
-rw-r--r--gcc/config/m68k/m68k.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/gcc/config/m68k/m68k.h b/gcc/config/m68k/m68k.h
index d1266f18e4b..1eebad7687c 100644
--- a/gcc/config/m68k/m68k.h
+++ b/gcc/config/m68k/m68k.h
@@ -81,14 +81,15 @@ extern int target_flags;
/* Compile (actually, link) for Sun SKY board. */
#define TARGET_SKY (target_flags & 0200)
-/* Optimize for 68040.
+/* Optimize for 68040, but still allow execution on 68020
+ (-m68020-40 or -m68040).
The 68040 will execute all 68030 and 68881/2 instructions, but some
of them must be emulated in software by the OS. When TARGET_68040 is
turned on, these instructions won't be used. This code will still
run on a 68030 and 68881/2. */
#define TARGET_68040 (target_flags & 0400)
/* Support 68040 fp instructions. */
#define TARGET_68040_ONLY (target_flags & 01000)
/* Macro to define tables used to set the flags.
@@ -114,10 +115,10 @@ extern int target_flags;
{ "nofpa", -0100}, \
{ "sky", 0200}, \
{ "nosky", -0200}, \
- { "68040", 0407}, \
+ { "68020-40", 0407}, \
{ "68030", -01400}, \
{ "68030", 7}, \
- { "68040-only", 01000}, \
+ { "68040", 01000}, \
{ "", TARGET_DEFAULT}}
/* TARGET_DEFAULT is defined in sun*.h and isi.h, etc. */
@@ -81,14 +81,15 @@ extern int target_flags;
turned on, these instructions won't be used. This code will still
run on a 68030 and 68881/2. */
-#define TARGET_68040 (target_flags & 0400)
+#define TARGET_68040 (target_flags & 01400)
-/* Support 68040 fp instructions. */
+/* Use the 68040-only fp instructions (-m68040). */
#define TARGET_68040_ONLY (target_flags & 01000)
/* Macro to define tables used to set the flags.